Method: Aws::XRay::Client#get_indexing_rules

Defined in:
lib/aws-sdk-xray/client.rb

#get_indexing_rules(params = {}) ⇒ Types::GetIndexingRulesResult

Retrieves all indexing rules.

Indexing rules are used to determine the server-side sampling rate for spans ingested through the CloudWatchLogs destination and indexed by X-Ray. For more information, see [Transaction Search].

[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Transaction-Search.html

Examples:

Request syntax with placeholder values


resp = client.get_indexing_rules({
  next_token: "String",
})

Response structure


resp.indexing_rules #=> Array
resp.indexing_rules[0].name #=> String
resp.indexing_rules[0].modified_at #=> Time
resp.indexing_rules[0].rule.probabilistic.desired_sampling_percentage #=> Float
resp.indexing_rules[0].rule.probabilistic.actual_sampling_percentage #=> Float
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :next_token (String)

    Specify the pagination token returned by a previous request to retrieve the next page of indexes.

Returns:

See Also:



985
986
987
988
# File 'lib/aws-sdk-xray/client.rb', line 985

def get_indexing_rules(params = {}, options = {})
  req = build_request(:get_indexing_rules, params)
  req.send_request(options)
end