Class: Aws::XRay::Types::GetInsightSummariesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-xray/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTime

The end of the time frame in which the insights ended. The end time can’t be more than 30 days old.



1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
# File 'lib/aws-sdk-xray/types.rb', line 1024

class GetInsightSummariesRequest < Struct.new(
  :states,
  :group_arn,
  :group_name,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#group_arnString

The Amazon Resource Name (ARN) of the group. Required if the GroupName isn’t provided.



1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
# File 'lib/aws-sdk-xray/types.rb', line 1024

class GetInsightSummariesRequest < Struct.new(
  :states,
  :group_arn,
  :group_name,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

The name of the group. Required if the GroupARN isn’t provided.



1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
# File 'lib/aws-sdk-xray/types.rb', line 1024

class GetInsightSummariesRequest < Struct.new(
  :states,
  :group_arn,
  :group_name,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to display.



1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
# File 'lib/aws-sdk-xray/types.rb', line 1024

class GetInsightSummariesRequest < Struct.new(
  :states,
  :group_arn,
  :group_name,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Pagination token.



1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
# File 'lib/aws-sdk-xray/types.rb', line 1024

class GetInsightSummariesRequest < Struct.new(
  :states,
  :group_arn,
  :group_name,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The beginning of the time frame in which the insights started. The start time can’t be more than 30 days old.



1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
# File 'lib/aws-sdk-xray/types.rb', line 1024

class GetInsightSummariesRequest < Struct.new(
  :states,
  :group_arn,
  :group_name,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#statesArray<String>

The list of insight states.



1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
# File 'lib/aws-sdk-xray/types.rb', line 1024

class GetInsightSummariesRequest < Struct.new(
  :states,
  :group_arn,
  :group_name,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end