Method: Aws::XRay::Types::UpdateGroupRequest#insights_configuration
- Defined in:
- lib/aws-sdk-xray/types.rb
#insights_configuration ⇒ Types::InsightsConfiguration
The structure containing configurations related to insights.
-
The InsightsEnabled boolean can be set to true to enable insights for the group or false to disable insights for the group.
-
The NotificationsEnabled boolean can be set to true to enable insights notifications for the group. Notifications can only be enabled on a group with InsightsEnabled set to true.
3831 3832 3833 3834 3835 3836 3837 3838 |
# File 'lib/aws-sdk-xray/types.rb', line 3831 class UpdateGroupRequest < Struct.new( :group_name, :group_arn, :filter_expression, :insights_configuration) SENSITIVE = [] include Aws::Structure end |